/*******************************************************************************
 * Copyright (c) 2009, 2013 Oracle and/or its affiliates. All rights reserved.
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0
 * which accompanies this distribution.
 * The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
 * and the Eclipse Distribution License is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 *
 * Contributors:
 *     Oracle - initial API and implementation
 *
 ******************************************************************************/
package org.eclipse.persistence.tools.utility.model.listener;

import org.eclipse.persistence.tools.utility.ObjectTools;
import org.eclipse.persistence.tools.utility.model.event.CollectionAddEvent;
import org.eclipse.persistence.tools.utility.model.event.CollectionChangeEvent;
import org.eclipse.persistence.tools.utility.model.event.CollectionClearEvent;
import org.eclipse.persistence.tools.utility.model.event.CollectionRemoveEvent;
import org.eclipse.persistence.tools.utility.model.event.ListAddEvent;
import org.eclipse.persistence.tools.utility.model.event.ListChangeEvent;
import org.eclipse.persistence.tools.utility.model.event.ListClearEvent;
import org.eclipse.persistence.tools.utility.model.event.ListMoveEvent;
import org.eclipse.persistence.tools.utility.model.event.ListRemoveEvent;
import org.eclipse.persistence.tools.utility.model.event.ListReplaceEvent;
import org.eclipse.persistence.tools.utility.model.event.PropertyChangeEvent;
import org.eclipse.persistence.tools.utility.model.event.StateChangeEvent;

/**
 * Convenience implementation of {@link ChangeListener}.
 * <p>
 * Provisional API: This class is part of an interim API that is still
 * under development and expected to change significantly before reaching
 * stability. It is available at this early stage to solicit feedback from
 * pioneering adopters on the understanding that any code that uses this API
 * will almost certainly be broken (repeatedly) as the API evolves.
 */
public class ChangeAdapter
	implements ChangeListener
{
	public ChangeAdapter() {
		super();
	}

	// ***** state
	@Override
	public void stateChanged(StateChangeEvent event) {
		// do nothing
	}

	// ***** property
	@Override
	public void propertyChanged(PropertyChangeEvent event) {
		// do nothing
	}

	// ***** collection
	@Override
	public void itemsAdded(CollectionAddEvent event) {
		// do nothing
	}

	@Override
	public void itemsRemoved(CollectionRemoveEvent event) {
		// do nothing
	}

	@Override
	public void collectionCleared(CollectionClearEvent event) {
		// do nothing
	}

	@Override
	public void collectionChanged(CollectionChangeEvent event) {
		// do nothing
	}

	// ***** list
	@Override
	public void itemsAdded(ListAddEvent event) {
		// do nothing
	}

	@Override
	public void itemsRemoved(ListRemoveEvent event) {
		// do nothing
	}

	@Override
	public void itemsReplaced(ListReplaceEvent event) {
		// do nothing
	}

	@Override
	public void itemsMoved(ListMoveEvent event) {
		// do nothing
	}

	@Override
	public void listCleared(ListClearEvent event) {
		// do nothing
	}

	@Override
	public void listChanged(ListChangeEvent event) {
		// do nothing
	}

	@Override
	public String toString() {
		return ObjectTools.toString(this);
	}
}